package ochre

  1. Overview
  2. Docs

1.0.0

  • Initial release of ochre, a syntax highlighter inspired by Shiki, using TextMate grammars and themes to produce accurate, beautiful syntax highlighting. It supports HTML output with inline styles, ANSI terminal colors, and raw token output
  • Initial release of ochre-cli, a CLI tool for highlighting source code using TextMate grammars and themes